lock_region

Function lock_region 

pub fn lock_region(ptr: *const u8, len: usize) -> Result<()>
Lock a memory region to reduce the chance of page-out.

Example

let bytes = [1_u8, 2, 3, 4];
kernelkit::mlock::lock_region(bytes.as_ptr(), bytes.len())?;
kernelkit::mlock::unlock_region(bytes.as_ptr(), bytes.len())?;

Errors

Returns an error if the kernel rejects the mlock request.