Module mmap

Module mmap 

Shared mmap-backed allocation primitives.

Structs

MmapBlock
A raw block of writable virtual memory allocated from the operating system.

Enums

MmapAdvice
Kernel advice hints for memory-mapped files.

Functions

open_read
Open a file as a read-only memory map with optimal kernel hints.
open_read_with_size
Open a file as a read-only map after validating its on-disk size.
open_with_advice
Open a file as a read-only memory map with explicit advice.
release
Release pages backing this mmap region back to the kernel.