Shared mmap-backed allocation primitives.
Structs
- Mmap
Block - A raw block of writable virtual memory allocated from the operating system.
Enums
- Mmap
Advice - Kernel advice hints for memory-mapped files.
Functions
- open_
read - Open a file as a read-only memory map with optimal kernel hints.
- open_
read_ with_ size - Open a file as a read-only map after validating its on-disk size.
- open_
with_ advice - Open a file as a read-only memory map with explicit advice.
- release
- Release pages backing this mmap region back to the kernel.